#!/bin/bash

softversion='23.2'
packageversion='72.1'
softname='lilo'
arch='i486'
cpu='i686'

PKGBUILD=$(pwd)

SRC="$PKGBUILD/$softname-$softversion"

package="$softname-$softversion-$arch-$packageversion"

PKG="/tmp/$package"


cd $PKGBUILD
rm -rf $SRC
tar -xvf $SRC.tar.gz
rm -f $PKG.tgz
rm -rf $PKG
mkdir -p $PKG
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mcpu=$cpu"

cd $SRC
make all
make install DESTDIR=$PKG

# Description file
mkdir -p $PKG/install

cat << "EODESC" > $PKG/install/slack-desc
lilo: lilo (Linux Loader)
lilo:
lilo: Generic Boot Loader for Linux ('LInux LOader') by Werner Almesberger.
lilo: LILO boots Linux from your hard drive. It can also boot other
lilo: operating systems such as MS-DOS and OS/2, and can even boot DOS from
lilo: the second hard drive. LILO comes with utilities and documentation
lilo: that make it easier to install, such as 'liloconfig' and 'QuickStart'.
lilo: NOTE: Installing boot loaders is inherently dangerous. Be sure to have
lilo: some means to boot your system from a different media if you install
lilo: LILO on your hard disk.
lilo:
EODESC

rm $PKG/boot/*
rm -rf $PKG/etc/kernel
rm -rf $PKG/etc/initramfs

chmod 755 $PKGBUILD/liloconfig $PKGBUILD/liloz
mv $PKG/sbin/lilo $PKG/sbin/lilo-bin
rm -f $PKG/usr/sbin/liloconfig
cp -pf $PKGBUILD/liloconfig $PKG/sbin/
cp -pf $PKGBUILD/liloz $PKG/sbin/lilo
mv $PKGBUILD/usr/sbin/* $PKG/sbin/

chmod 644 $PKGBUILD/splash.bmp
cp -pf $PKGBUILD/splash.bmp $PKG/boot/

mkdir -p $PKG/usr/doc/$softname-$softversion
cp -a CHANGES COPYING COPYRIGHT INCOMPAT QuickInst READM* doc sample $PKG/usr/doc/$softname-$softversion/

mv $PKG/usr/share/man $PKG/usr/man
rm -rf $PKG/usr/share
gzip -9 $PKG/usr/man/man?/*

( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $PKG/usr/src/$softname-$softversion
cp $PKGBUILD/build-$softname.sh $PKG/usr/src/$softname-$softversion

chown -R root:root $PKG
cd $PKG
makepkg -l y -c n $PKG.txz
rm -rf $PKG
rm -rf $SRC




